@@ -26,7 +26,7 @@ This module is very ugly and is intended to be rewritten sometimes.
 """
 
 __author__  = "Milan Zamazal <pdm@freesoft.cz>"
-__version__ = "$Id: cgiscript.py,v 1.24 2000/01/25 20:40:59 pdm Exp $"
+__version__ = "$Id: cgiscript.py,v 1.28 2000/09/08 20:04:56 pdm Exp $"
 __copyright__ = "GNU General Public License, version 2"
 
 
@@ -411,9 +411,12 @@ def submit (form):
     # New report
     if not form.keys ():
         categories = categories_full ()
-        if config.AUTO_CONFIDENTIAL and access != config.ACCESS.FULL:
-            categories = filter (lambda c: not c[1], categories)
-        categories = map (lambda c: c[0], categories)
+        try:
+            if config.AUTO_CONFIDENTIAL and access != config.ACCESS.FULL:
+                categories = filter (lambda c: not c[1], categories)
+            categories = map (lambda c: c[0], categories)
+        except:
+            categories = []
         try:
             categories.remove ('pending')
         except:
@@ -440,18 +443,19 @@ def submit (form):
     if not form.has_key ('email'):
         report_error (L('No e-mail given, where to send the answers to?'))
         return
-    form['confidential'] = 'yes'
+    confidential = 'yes'
     categories = categories_full ()
     if config.AUTO_CONFIDENTIAL and form.has_key ('category'):
         cat = form['category']
         for c in categories:
             if c[0] == cat:
                 if not c[1]:
-                    form['confidential'] = 'no'
+                    confidential = 'no'
                 break
     else:
         if not form.has_key ('confidential'):
-            form['confidential'] = 'no'    
+            confidential = 'no'
+    form['confidential'] = confidential
     for k in ('description', 'how-to-repeat', 'fix', 'environment'):
         if form.has_key (k):
             form[k] = remove_crs (form[k])
@@ -707,10 +711,15 @@ def query (form):
     else:
         cat_limit = ''
         cat_limited = 1
-    query, result = G.query (items)
-    if type (result) == type (''):
-        report_error (L('Query error:\n%s') % result)
-    elif result == []:
+    query, full_result = G.query (items)
+    if type (full_result) == type (''):
+        report_error (L('Query error:\n%s') % full_result)
+    result = []
+    for r in full_result:
+        p = G.problem (r[0])
+        if config.ACCESS.granted (config.ACCESS.VIEW, p):
+            result.append (r)
+    if result == []:
         report_error (L('Nothing found.'))
     else:
         base = url_path ()
@@ -757,6 +766,7 @@ def query (form):
         if sortby:
             result.sort (func)
         for l in result:
+            id = l[0]
             if not config.DISPLAY_ORGANIZATION:
                 del l[6]
             row = HTMLgen.TR ()
@@ -764,7 +774,6 @@ def query (form):
                 pinfo = os.environ['PATH_INFO']
             else:
                 pinfo = ''
-            id = l[0]
             link = HTMLgen.Href ("%s?id=%s" % (gen_submit_url ('view'), id),
                                  id)
             row.append (HTMLgen.TD (link, align="right"))
