@@ -27,7 +27,7 @@ GNATS databases are accessed only by GNATS commands (both public and internal).
 """
 
 __author__  = "Milan Zamazal <pdm@freesoft.cz>"
-__version__ = "$Id: gnats.py,v 1.18 2000/03/05 08:09:44 pdm Exp $"
+__version__ = "$Id: gnats.py,v 1.20 2000/07/24 19:08:44 pdm Exp $"
 __copyright__ = "GNU General Public License, version 2"
 
 
@@ -364,7 +364,7 @@ class Gnats:
                     break
                 line = string.rstrip (line)
                 line = string.split (line, ':')
-                if line[1][0] == '*':
+                if line[1] and line[1][0] == '*':
                     confidential = 1
                     line[1] = line[1][1:]
                 else:
@@ -638,8 +638,8 @@ class Gnats:
             if result:
                 return result
         try:
-            inp, outp = popen2.popen2 (os.path.join (config.GNATS_PRG_DIR,
-                                                     'pr-edit') + ' -c')
+            command = os.path.join (config.GNATS_PRG_DIR, 'pr-edit') + ' -c'
+            inp, outp = popen2.popen2 (self._directory_command (command))
             outp.write (self.dump (problem))
             outp.close ()
             result = inp.read ()
